@@ -9,10 +9,13 @@ my %opt;
 my ($opt_help, $opt_man);
 
 GetOptions(
+  '4!'            => \$opt{4},
+  '6!'            => \$opt{6},
   'version=i'     => \$opt{version},
   'community=s'   => \$opt{community},
   'integer|n=i'   => \$opt{integer},
   'string=s'      => \$opt{string},
+  'x|hex=s'       => \$opt{hexstring},
   'oid=s'         => \$opt{oid},
   'ip|A=s'        => \$opt{ip},
   'counter32|C=i' => \$opt{counter32},
@@ -27,6 +30,12 @@ GetOptions(
 pod2usage(-verbose => 1) if defined $opt_help;
 pod2usage(-verbose => 2) if defined $opt_man;
 
+# Default to IPv4
+my $family = 'udp4';
+if ($opt{6}) {
+    $family = 'udp6'
+}
+
 # Make sure at least one host was provided
 if (!@ARGV) {
     $ARGV[0] = 'localhost'
@@ -36,6 +45,8 @@ $opt{version}   = $opt{version}   || 1;
 $opt{community} = $opt{community} || 'public';
 $opt{integer}   = $opt{integer}   || 1;
 $opt{string}    = $opt{string}    || 'String';
+$opt{hexstring} = $opt{hexstring} || '0102030405060708';
+$opt{hexstring} = pack ("H*", $opt{hexstring});
 $opt{oid}       = $opt{oid}       || '1.2.3.4.5.6.7.8.9';
 $opt{ip}        = $opt{ip}        || '10.10.10.1';
 $opt{counter32} = $opt{counter32} || 32323232;
@@ -47,11 +58,12 @@ $opt{inform}    = $opt{inform}    || 0;
 for my $host (@ARGV) {
 
     my ($session, $error) = Net::SNMP->session(
-                                               -hostname  => $host,
-                                               -version   => $opt{version},
-                                               -community => $opt{community},
-                                               -port      => SNMP_TRAP_PORT
-                                              );
+        -hostname  => $host,
+        -version   => $opt{version},
+        -community => $opt{community},
+        -domain    => $family,
+        -port      => SNMP_TRAP_PORT
+    );
 
     if (!defined($session)) {
        printf "Error: Starting SNMP session - %s\n", $error;
@@ -67,12 +79,13 @@ for my $host (@ARGV) {
             -varbindlist  => [
                 '1.3.6.1.4.1.50000.1.3',  INTEGER,           $opt{integer},
                 '1.3.6.1.4.1.50000.1.4',  OCTET_STRING,      $opt{string},
-                '1.3.6.1.4.1.50000.1.5',  OBJECT_IDENTIFIER, $opt{oid},
-                '1.3.6.1.4.1.50000.1.6',  IPADDRESS,         $opt{ip},
-                '1.3.6.1.4.1.50000.1.7',  COUNTER32,         $opt{counter32},
-                '1.3.6.1.4.1.50000.1.8',  GAUGE32,           $opt{gauge32},
-                '1.3.6.1.4.1.50000.1.9',  TIMETICKS,         $opt{timeticks},
-                '1.3.6.1.4.1.50000.1.10', OPAQUE,            $opt{opaque}
+                '1.3.6.1.4.1.50000.1.5',  OCTET_STRING,      $opt{hexstring},
+                '1.3.6.1.4.1.50000.1.6',  OBJECT_IDENTIFIER, $opt{oid},
+                '1.3.6.1.4.1.50000.1.7',  IPADDRESS,         $opt{ip},
+                '1.3.6.1.4.1.50000.1.8',  COUNTER32,         $opt{counter32},
+                '1.3.6.1.4.1.50000.1.9',  GAUGE32,           $opt{gauge32},
+                '1.3.6.1.4.1.50000.1.10', TIMETICKS,         $opt{timeticks},
+                '1.3.6.1.4.1.50000.1.11', OPAQUE,            $opt{opaque}
             ]
         )
     } elsif ($opt{version} == 2) {
@@ -83,12 +96,13 @@ for my $host (@ARGV) {
                     '1.3.6.1.6.3.1.1.4.1.0',  OBJECT_IDENTIFIER, '1.3.6.1.4.1.50000',
                     '1.3.6.1.4.1.50000.1.3',  INTEGER,           $opt{integer},
                     '1.3.6.1.4.1.50000.1.4',  OCTET_STRING,      $opt{string},
-                    '1.3.6.1.4.1.50000.1.5',  OBJECT_IDENTIFIER, $opt{oid},
-                    '1.3.6.1.4.1.50000.1.6',  IPADDRESS,         $opt{ip},
-                    '1.3.6.1.4.1.50000.1.7',  COUNTER32,         $opt{counter32},
-                    '1.3.6.1.4.1.50000.1.8',  GAUGE32,           $opt{gauge32},
-                    '1.3.6.1.4.1.50000.1.9',  TIMETICKS,         $opt{timeticks},
-                    '1.3.6.1.4.1.50000.1.10', OPAQUE,            $opt{opaque}
+                    '1.3.6.1.4.1.50000.1.5',  OCTET_STRING,      $opt{hexstring},
+                    '1.3.6.1.4.1.50000.1.6',  OBJECT_IDENTIFIER, $opt{oid},
+                    '1.3.6.1.4.1.50000.1.7',  IPADDRESS,         $opt{ip},
+                    '1.3.6.1.4.1.50000.1.8',  COUNTER32,         $opt{counter32},
+                    '1.3.6.1.4.1.50000.1.9',  GAUGE32,           $opt{gauge32},
+                    '1.3.6.1.4.1.50000.1.10', TIMETICKS,         $opt{timeticks},
+                    '1.3.6.1.4.1.50000.1.11', OPAQUE,            $opt{opaque}
                 ]
             )
         } else {
@@ -98,12 +112,13 @@ for my $host (@ARGV) {
                     '1.3.6.1.6.3.1.1.4.1.0',  OBJECT_IDENTIFIER, '1.3.6.1.4.1.50000',
                     '1.3.6.1.4.1.50000.1.3',  INTEGER,           $opt{integer},
                     '1.3.6.1.4.1.50000.1.4',  OCTET_STRING,      $opt{string},
-                    '1.3.6.1.4.1.50000.1.5',  OBJECT_IDENTIFIER, $opt{oid},
-                    '1.3.6.1.4.1.50000.1.6',  IPADDRESS,         $opt{ip},
-                    '1.3.6.1.4.1.50000.1.7',  COUNTER32,         $opt{counter32},
-                    '1.3.6.1.4.1.50000.1.8',  GAUGE32,           $opt{gauge32},
-                    '1.3.6.1.4.1.50000.1.9',  TIMETICKS,         $opt{timeticks},
-                    '1.3.6.1.4.1.50000.1.10', OPAQUE,            $opt{opaque}
+                    '1.3.6.1.4.1.50000.1.5',  OCTET_STRING,      $opt{hexstring},
+                    '1.3.6.1.4.1.50000.1.6',  OBJECT_IDENTIFIER, $opt{oid},
+                    '1.3.6.1.4.1.50000.1.7',  IPADDRESS,         $opt{ip},
+                    '1.3.6.1.4.1.50000.1.8',  COUNTER32,         $opt{counter32},
+                    '1.3.6.1.4.1.50000.1.9',  GAUGE32,           $opt{gauge32},
+                    '1.3.6.1.4.1.50000.1.10', TIMETICKS,         $opt{timeticks},
+                    '1.3.6.1.4.1.50000.1.11', OPAQUE,            $opt{opaque}
                 ]
             )
         }
@@ -133,18 +148,22 @@ The user can configure the values with the options.
   -----------              ---------------    -------
   1.3.6.1.4.1.50000.1.3    INTEGER            1
   1.3.6.1.4.1.50000.1.4    OCTET_STRING       String
-  1.3.6.1.4.1.50000.1.5    OBJECT_IDENTIFIER  1.2.3.4.5.6.7.8.9
-  1.3.6.1.4.1.50000.1.6    IPADDRESS          10.10.10.1
-  1.3.6.1.4.1.50000.1.7    COUNTER32          32323232
-  1.3.6.1.4.1.50000.1.8    GAUGE32            42424242
-  1.3.6.1.4.1.50000.1.9    TIMETICKS          [time()]
-  1.3.6.1.4.1.50000.1.10   OPAQUE             opaque data
+  1.3.6.1.4.1.50000.1.5    OCTET_STRING       0x0102030405060708
+  1.3.6.1.4.1.50000.1.6    OBJECT_IDENTIFIER  1.2.3.4.5.6.7.8.9
+  1.3.6.1.4.1.50000.1.7    IPADDRESS          10.10.10.1
+  1.3.6.1.4.1.50000.1.8    COUNTER32          32323232
+  1.3.6.1.4.1.50000.1.9    GAUGE32            42424242
+  1.3.6.1.4.1.50000.1.10   TIMETICKS          [time()]
+  1.3.6.1.4.1.50000.1.11   OPAQUE             opaque data
 
 =head1 OPTIONS
 
  host           The host to send to.
                 DEFAULT:  (or not specified) localhost.
 
+ -4             Force IPv4.
+ -6             Force IPv6 (overrides -4).
+
  -A <IP_ADDR>   SNMP IPADDRESS value.
  --ip           DEFAULT:  (or not specified) 10.10.10.1
 
@@ -157,7 +176,7 @@ The user can configure the values with the options.
  -g #           SNMP GAUGE32 value.
  --gauge32      DEFAULT:  (or not specified) 42424242
 
- -I #           Send SNMPv2 InformRequest instead of SNMPv2 Trap.
+ -I             Send SNMPv2 InformRequest instead of SNMPv2 Trap.
  --inform       Only valid with -v 2.
                 DEFAULT:  (or not specified) [SNMPv1 trap]
 
@@ -176,6 +195,10 @@ The user can configure the values with the options.
  -t #           SNMP TIMETICKS value.
  --timeticks    DEFAULT:  (or not specified) [time()]
 
+ -x <09af>      SNMP OCTET_STRING consisting of hex data (non-
+ --hex          printable ASCII).
+                DEFAULT:  (or not specified) 0102030405060708
+
  -v #           SNMP Version (v1 or v2c).  Use '1' or '2'.
  --version      DEFAULT:  (or not specified) 1
 
