@@ -204,12 +204,12 @@ sub test4 {
             } else {
 if ($VERBOSE) {
                 print "  -- $_ --\n";
-                print "  peeraddr  = "; if (defined($trap->peeraddr)      && ($trap->peeraddr eq "127.0.0.1"))              { printf "%s\n", $trap->peeraddr                           } else { printf "  !ERROR! - %s\n", $trap->peeraddr; $FAILED++ }
-                print "  peerport  = "; if (defined($trap->peerport)      && ($trap->peerport =~ /^\d{1,5}$/))              { printf "%s\n", $trap->peerport                           } else { printf "  !ERROR! - %s\n", $trap->peerport; $FAILED++ }
+                print "  remoteaddr = "; if (defined($trap->remoteaddr)  && ($trap->remoteaddr eq "127.0.0.1"))            { printf "%s\n", $trap->remoteaddr                         } else { printf "  !ERROR! - %s\n", $trap->remoteaddr; $FAILED++ }
+                print "  remoteport = "; if (defined($trap->remoteport)  && ($trap->remoteport =~ /^\d{1,5}$/))            { printf "%s\n", $trap->remoteport                         } else { printf "  !ERROR! - %s\n", $trap->remoteport; $FAILED++ }
 
-                print "  version   = "; if (defined($trap->version)       && ($trap->version =~ /^[12]$/))                  { printf "%s\n", $trap->version                            } else { printf "  !ERROR! - %s\n", $trap->version;   $FAILED++ }
-                print "  community = "; if (defined($trap->community)     && ($trap->community eq 'public'))                { printf "%s\n", $trap->community                          } else { printf "  !ERROR! - %s\n", $trap->community; $FAILED++ }
-                print "  pdu_type  = "; if (defined($trap->pdu_type)      && ($trap->pdu_type(1) =~ /^[467]$/))             { printf "%s\n", $trap->pdu_type; $T{$trap->pdu_type(1)}++ } else { printf "  !ERROR! - %s\n", $trap->pdu_type;  $FAILED++ }
+                print "  version    = "; if (defined($trap->version)     && ($trap->version =~ /^[12]$/))                  { printf "%s\n", $trap->version                            } else { printf "  !ERROR! - %s\n", $trap->version;   $FAILED++ }
+                print "  community  = "; if (defined($trap->community)   && ($trap->community eq 'public'))                { printf "%s\n", $trap->community                          } else { printf "  !ERROR! - %s\n", $trap->community; $FAILED++ }
+                print "  pdu_type   = "; if (defined($trap->pdu_type)    && ($trap->pdu_type(1) =~ /^[467]$/))             { printf "%s\n", $trap->pdu_type; $T{$trap->pdu_type(1)}++ } else { printf "  !ERROR! - %s\n", $trap->pdu_type;  $FAILED++ }
                 # Make sure we've seen each PDU type only once
                 for (keys(%T)) {
                     if ($T{$_} > 1) {
@@ -217,33 +217,33 @@ if ($VERBOSE) {
                     }
                 }
                 if ($trap->version == 1) {
-                print "  ent_OID   = "; if (defined($trap->ent_OID)       && ($trap->ent_OID eq "1.3.6.1.4.1.50000"))       { printf "%s\n", $trap->ent_OID       } else { printf "  !ERROR! - %s\n", $trap->ent_OID;       $FAILED++ }
-                print "  agentaddr = "; if (defined($trap->agentaddr)     && ($trap->agentaddr eq "127.0.0.1"))             { printf "%s\n", $trap->agentaddr     } else { printf "  !ERROR! - %s\n", $trap->agentaddr;     $FAILED++ }
-                print "  generic   = "; if (defined($trap->generic_trap)  && ($trap->generic_trap eq "ENTERPRISESPECIFIC")) { printf "%s\n", $trap->generic_trap  } else { printf "  !ERROR! - %s\n", $trap->generic_trap;  $FAILED++ }
-                print "  specific  = "; if (defined($trap->specific_trap) && ($trap->specific_trap == 1))                   { printf "%s\n", $trap->specific_trap } else { printf "  !ERROR! - %s\n", $trap->Specific_trap; $FAILED++ }
-                print "  timeticks = "; if (defined($trap->timeticks)     && ($trap->timeticks =~ /^\d+$/))                 { printf "%s\n", $trap->timeticks     } else { printf "  !ERROR! - %s\n", $trap->timeticks;     $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'})  && ($trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'} == 1))                   { printf "%s\n", $trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'})  && ($trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'} eq 'String'))            { printf "%s\n", $trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'})  && ($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'} eq '1.2.3.4.5.6.7.8.9')) { printf "%s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'})  && ($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'} eq '10.10.10.1'))        { printf "%s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'})  && ($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'} == 32323232))            { printf "%s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'})  && ($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'} == 42424242))            { printf "%s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'})  && ($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'} =~ /^\d+$/))             { printf "%s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'}) && ($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'} eq 'opaque data'))      { printf "%s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'} } else { printf "  !ERROR! - %s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'}; $FAILED++ }
+                print "  ent_OID    = "; if (defined($trap->ent_OID)       && ($trap->ent_OID eq "1.3.6.1.4.1.50000"))       { printf "%s\n", $trap->ent_OID       } else { printf "  !ERROR! - %s\n", $trap->ent_OID;       $FAILED++ }
+                print "  agentaddr  = "; if (defined($trap->agentaddr)     && ($trap->agentaddr eq "127.0.0.1"))             { printf "%s\n", $trap->agentaddr     } else { printf "  !ERROR! - %s\n", $trap->agentaddr;     $FAILED++ }
+                print "  generic    = "; if (defined($trap->generic_trap)  && ($trap->generic_trap eq "ENTERPRISESPECIFIC")) { printf "%s\n", $trap->generic_trap  } else { printf "  !ERROR! - %s\n", $trap->generic_trap;  $FAILED++ }
+                print "  specific   = "; if (defined($trap->specific_trap) && ($trap->specific_trap == 1))                   { printf "%s\n", $trap->specific_trap } else { printf "  !ERROR! - %s\n", $trap->Specific_trap; $FAILED++ }
+                print "  timeticks  = "; if (defined($trap->timeticks)     && ($trap->timeticks =~ /^\d+$/))                 { printf "%s\n", $trap->timeticks     } else { printf "  !ERROR! - %s\n", $trap->timeticks;     $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'})  && ($trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'} == 1))                   { printf "%s\n", $trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[0]->{'1.3.6.1.4.1.50000.1.3'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'})  && ($trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'} eq 'String'))            { printf "%s\n", $trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[1]->{'1.3.6.1.4.1.50000.1.4'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'})  && ($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'} eq '1.2.3.4.5.6.7.8.9')) { printf "%s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.5'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'})  && ($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'} eq '10.10.10.1'))        { printf "%s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.6'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'})  && ($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'} == 32323232))            { printf "%s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.7'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'})  && ($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'} == 42424242))            { printf "%s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.8'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'})  && ($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'} =~ /^\d+$/))             { printf "%s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.9'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'}) && ($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'} eq 'opaque data'))      { printf "%s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'} } else { printf "  !ERROR! - %s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.10'}; $FAILED++ }
                 } else {
-                print "  requestID = "; if (defined($trap->request_ID)    && ($trap->request_ID =~ /^\d+$/))                { printf "%s\n", $trap->request_ID    } else { printf "  !ERROR! - %s\n", $trap->request_ID;   $FAILED++ } 
-                print "  errorstat = "; if (defined($trap->error_status)  && ($trap->error_status =~ /^\d+$/))              { printf "%s\n", $trap->error_status  } else { printf "  !ERROR! - %s\n", $trap->error_status; $FAILED++ } 
-                print "  errorindx = "; if (defined($trap->error_index)   && ($trap->error_index =~ /^\d+$/))               { printf "%s\n", $trap->error_index   } else { printf "  !ERROR! - %s\n", $trap->error_index;  $FAILED++ } 
-                print "  varbind   = "; if (defined($trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'})      && ($trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'} =~ /^\d+$/))                 { printf "%s\n", $trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'}      } else { printf "  !ERROR! - %s\n", $trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'})  && ($trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'} eq '1.3.6.1.4.1.50000')) { printf "%s\n", $trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'})  && ($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'} == 1))                   { printf "%s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'})  && ($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'} eq 'String'))            { printf "%s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'})  && ($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'} eq '1.2.3.4.5.6.7.8.9')) { printf "%s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'})  && ($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'} eq '10.10.10.1'))        { printf "%s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'})  && ($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'} == 32323232))            { printf "%s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'})  && ($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'} == 42424242))            { printf "%s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'})  && ($trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'} =~ /^\d+$/))             { printf "%s\n", $trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'}; $FAILED++ }
-                print "  varbind   = "; if (defined($trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'}) && ($trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'} eq 'opaque data'))      { printf "%s\n", $trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'} } else { printf "  !ERROR! - %s\n", $trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'}; $FAILED++ }
+                print "  requestID  = "; if (defined($trap->request_ID)    && ($trap->request_ID =~ /^\d+$/))                { printf "%s\n", $trap->request_ID    } else { printf "  !ERROR! - %s\n", $trap->request_ID;   $FAILED++ } 
+                print "  errorstat  = "; if (defined($trap->error_status)  && ($trap->error_status =~ /^\d+$/))              { printf "%s\n", $trap->error_status  } else { printf "  !ERROR! - %s\n", $trap->error_status; $FAILED++ } 
+                print "  errorindx  = "; if (defined($trap->error_index)   && ($trap->error_index =~ /^\d+$/))               { printf "%s\n", $trap->error_index   } else { printf "  !ERROR! - %s\n", $trap->error_index;  $FAILED++ } 
+                print "  varbind    = "; if (defined($trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'})      && ($trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'} =~ /^\d+$/))                 { printf "%s\n", $trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'}      } else { printf "  !ERROR! - %s\n", $trap->varbinds->[0]->{'1.3.6.1.2.1.1.3.0'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'})  && ($trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'} eq '1.3.6.1.4.1.50000')) { printf "%s\n", $trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[1]->{'1.3.6.1.6.3.1.1.4.1.0'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'})  && ($trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'} == 1))                   { printf "%s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[2]->{'1.3.6.1.4.1.50000.1.3'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'})  && ($trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'} eq 'String'))            { printf "%s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[3]->{'1.3.6.1.4.1.50000.1.4'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'})  && ($trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'} eq '1.2.3.4.5.6.7.8.9')) { printf "%s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[4]->{'1.3.6.1.4.1.50000.1.5'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'})  && ($trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'} eq '10.10.10.1'))        { printf "%s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[5]->{'1.3.6.1.4.1.50000.1.6'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'})  && ($trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'} == 32323232))            { printf "%s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[6]->{'1.3.6.1.4.1.50000.1.7'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'})  && ($trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'} == 42424242))            { printf "%s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[7]->{'1.3.6.1.4.1.50000.1.8'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'})  && ($trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'} =~ /^\d+$/))             { printf "%s\n", $trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'}  } else { printf "  !ERROR! - %s\n", $trap->varbinds->[8]->{'1.3.6.1.4.1.50000.1.9'}; $FAILED++ }
+                print "  varbind    = "; if (defined($trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'}) && ($trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'} eq 'opaque data'))      { printf "%s\n", $trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'} } else { printf "  !ERROR! - %s\n", $trap->varbinds->[9]->{'1.3.6.1.4.1.50000.1.10'}; $FAILED++ }
                 }
 }
             }
@@ -275,12 +275,11 @@ sub test5 {
     # Start Server
     my $FAILED = 0;
 
-    use IO::Socket::IP -register;
-    my $snmptrapd = IO::Socket::IP->new(
+    use IO::Socket::INET;
+    my $snmptrapd = IO::Socket::INET->new(
                                           'Proto'     => 'udp',
                                           'LocalPort' => 162,
-                                          'Timeout'   => 10,
-                                          'Family'    => AF_INET
+                                          'Timeout'   => 10
                                          );
 
     if (!defined($snmptrapd)) {
